Man pages:

Item                             | Description
-------------------------------- | ---------------------------------------------------------------
[`derivepassphrase(1)`][dpp_man] | A deterministic, stateless password manager: command-line tool.

Top-level modules:

Module                           | Description
-------------------------------- | --------------------------------------------------------------------
[`derivepassphrase`][dpp_module] | Work-alike for vault(1) - deterministic, stateless password manager.
[`sequin`][]                     | Python port of Sequin, a pseudorandom number generator.
[`ssh_agent_client`][]           | A bare-bones SSH agent client supporting signing and key listing.

  [dpp_man]: reference/derivepassphrase.1.md
  [dpp_module]: reference/derivepassphrase.md
  [sequin]: reference/sequin.md
  [ssh_agent_client]: reference/ssh_agent_client.md
